%global srcname subliminal

Name:           python-%{srcname}
Version:        2.0.5
Release:        7%{?dist}
Summary:        Python library to search and download subtitles
License:        MIT
URL:            https://github.com/Diaoul/subliminal
Source:         https://github.com/Diaoul/%{srcname}/archive/%{version}/%{srcname}-%{version}.tar.gz
# Don't download sphinx interlink inventory files, instead use local ones (for those which are packaged)
Patch0:         python-subliminal_doc-inventories.patch
BuildArch:      noarch
BuildRequires:  python2-devel
BuildRequires:  python3-devel
# Doc building
BuildRequires:  python2-docs
BuildRequires:  python2-sphinx
BuildRequires:  python2-futures
BuildRequires:  python2-babelfish
BuildRequires:  python2-guessit
BuildRequires:  python2-sphinxcontrib-programoutput
BuildRequires:  python2-beautifulsoup4
BuildRequires:  python2-click
BuildRequires:  python-guessit-doc
BuildRequires:  python2-rarfile
BuildRequires:  python2-stevedore
BuildRequires:  python2-enzyme
BuildRequires:  python2-pysrt
BuildRequires:  python2-dogpile-cache
# Tests disabled
#BuildRequires:  python2-pytest-runner
#BuildRequires:  python3-pytest-runner
#BuildRequires:  python2-pytz
#BuildRequires:  python3-pytz
#BuildRequires:  python3-rarfile
#BuildRequires:  python2-appdirs
#BuildRequires:  python3-appdirs
#BuildRequires:  python2-six
#BuildRequires:  python3-six
#BuildRequires:  python3-pysrt
#BuildRequires:  python2-pbr
#BuildRequires:  python3-pbr
#BuildRequires:  python3-enzyme
#BuildRequires:  python3-stevedore
#BuildRequires:  python3-dogpile-cache
#BuildRequires:  python2-sympy
#BuildRequires:  python3-sympy
#BuildRequires:  python2-vcrpy
#BuildRequires:  python3-vcrpy
#BuildRequires:  python2-pytest-pep8
#BuildRequires:  python3-pytest-pep8
#BuildRequires:  python2-pytest-flakes
#BuildRequires:  python3-pytest-flakes
#BuildRequires:  python2-pytest-cov
#BuildRequires:  python3-pytest-cov
#BuildRequires:  python3-guessit

%global _description\
Subliminal is a Python library to search and download subtitles.\
It comes with an easy to use yet powerful CLI suitable for direct use or\
cron jobs.\
\
Subliminal uses multiple providers to give users a vast choice and have\
a better chance to find the best matching subtitles. Current supported\
providers are:\
\
 - Addic7ed\
 - LegendasTV\
 - NapiProjekt\
 - OpenSubtitles\
 - Podnapisi\
 - Shooter\
 - TheSubDB\
 - TvSubtitles

%description %_description

%package -n python2-%{srcname}
Summary:        %summary
%{?python_provide:%python_provide python2-%{srcname}}
Requires:       python2-babelfish
Requires:       python2-requests
Requires:       python2-guessit
Requires:       python2-pysrt
Requires:       python2-enzyme
Requires:       python2-beautifulsoup4
Requires:       python2-dogpile-cache
Requires:       python2-stevedore
Requires:       python2-chardet
Requires:       python2-rarfile
Suggests:       %{name}-doc

%description -n python2-%{srcname} %_description

%package -n python3-%{srcname}
Summary:        %summary
%{?python_provide:%python_provide python3-%{srcname}}
Requires:       python3-babelfish                   
Requires:       python3-requests
Requires:       python3-guessit
Requires:       python3-pysrt
Requires:       python3-enzyme                      
Requires:       python3-beautifulsoup4
Requires:       python3-dogpile-cache
Requires:       python3-stevedore
Requires:       python3-chardet
Requires:       python3-rarfile
Suggests:       %{name}-doc

%description -n python3-%{srcname} %_description

%package doc
Summary:        %summary

%description doc %_description

%prep
%autosetup -p1 -n %{srcname}-%{version}

%build
%py2_build
%py3_build

%install
%py2_install
%py3_install

pushd docs
# Add folder containing subliminal script to PATH
PYTHONPATH=%{buildroot}%{python3_sitelib} PATH=$PATH:%{buildroot}%{_bindir} %make_build html
PYTHONPATH=%{buildroot}%{python3_sitelib} PATH=$PATH:%{buildroot}%{_bindir} %make_build text
PYTHONPATH=%{buildroot}%{python3_sitelib} PATH=$PATH:%{buildroot}%{_bindir} %make_build man
find . -name .buildinfo -type f -delete
popd
install -D -m 0644 docs/_build/man/%{srcname}.1 %{buildroot}%{_mandir}/man1/%{srcname}.1

%check
# Tests disabled because they connect to online services
#%%{__python2} setup.py test
#%%{__python3} setup.py test

%files -n python2-%{srcname}
%license  LICENSE
%{python2_sitelib}/%{srcname}
%{python2_sitelib}/%{srcname}-%{version}-py*.egg-info

%files -n python3-%{srcname}
%license LICENSE
%{_bindir}/subliminal
%{python3_sitelib}/%{srcname}
%{python3_sitelib}/%{srcname}-%{version}-py*.egg-info

%files doc
%doc README.rst docs/_build/html docs/_build/text
%license LICENSE
%{_mandir}/man1/%{srcname}.1*

%changelog
* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.5-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jun 19 2018 Miro Hrončok <mhroncok@redhat.com> - 2.0.5-6
- Rebuilt for Python 3.7

* Sun Jun 10 2018 Juan Orti Alcaine <jorti@fedoraproject.org> - 2.0.5-5
- Add rarfile dependency

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.5-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Tue Sep 05 2017 Juan Orti Alcaine <jorti@fedoraproject.org> - 2.0.5-3
- Build docs

* Tue Aug 29 2017 Juan Orti Alcaine <jorti@fedoraproject.org> - 2.0.5-2
- Change Source URL
- Escape macros in comments
- Improve description

* Tue Aug 29 2017 Juan Orti Alcaine <jorti@fedoraproject.org> - 2.0.5-1
- Initial RPM release
